@@ -209,12 +209,20 @@ define ([
             maxlen: 30,
             populate: caches.populateSupervisorNick,
         },
+        ePhasReports: {
+            name: 'ePhasReports',
+            aclProfileRead: 'inactive',
+            aclProfileWrite: 'admin',
+            text: 'Direct reports',
+            prop: 'has_reports',
+            maxlen: 8,
+        },
         iNact: {
             name: 'iNact',
             aclProfileRead: 'active',
             aclProfileWrite: 'active',
             text: 'Activity',
-            prop: 'iNact',
+            prop: 'code',
             maxlen: 32,
             vetter: actLib.vetActivity,
         },
@@ -296,9 +304,17 @@ define ([
             aclProfileRead: 'active',
             aclProfileWrite: 'active',
             text: 'Description',
-            prop: 'iNdesc',
+            prop: 'long_desc',
             maxlen: 60,
         },
+        iNshortDesc: {
+            name: 'iNshortDesc',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Description',
+            prop: 'long_desc',
+            maxlen: 30,
+        },
         iNexistintvls: {
             name: 'iNexistintvls',
             aclProfileRead: 'inactive',
@@ -388,6 +404,15 @@ define ([
             maxlen: 20,
             vetter: datetime.vetTimeRange,
         },
+        iNtimerangeNoOffset: {
+            name: 'iNtimerangeNoOffset',
+            aclProfileRead: 'active',
+            aclProfileWrite: 'active',
+            text: 'Time range',
+            prop: 'iNtimerange',
+            maxlen: 20,
+            vetter: datetime.vetTimeRangeNoOffset,
+        },
         iNtoBeCreated: {
             name: 'textOnly',
             textOnly: "Interval to be created",
